@@ -1,11 +1,14 @@
 import re
 import sys
-import mapnik
 import urllib
 import socket
-
+    
 socket.setdefaulttimeout(6)
 
+from mapnik_utils.version_adapter import Mapnik
+
+mapnik = Mapnik()
+
 MERC_PROJ4 = '+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +no_defs +over'
 
 class EasyProjection(mapnik.Projection):
